@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 """
 Admin for the csv_generator app
 """
-from __future__ import unicode_literals
 from csv_generator.forms import CsvGeneratorForm, CsvGeneratorColumnForm
 from csv_generator.forms import CsvGeneratorColumnFormSet
 from csv_generator.models import CsvGenerator, CsvGeneratorColumn
@@ -68,8 +66,7 @@ class CsvExportAdmin(admin.ModelAdmin):
     """
     actions = ['export_to_csv']
 
-    @staticmethod
-    def export_to_csv_view(request, **kwargs):
+    def export_to_csv_view(self, request, **kwargs):
         """
         Helper method for rendering a view to export a queryset to csv
 
@@ -81,6 +78,7 @@ class CsvExportAdmin(admin.ModelAdmin):
 
         :return: HttpResponse instance
         """
+        kwargs['preserved_filters'] = request.GET.urlencode()
         return CsvExportView.as_view()(request, **kwargs)
 
     def export_to_csv(self, request, queryset):
@@ -112,7 +110,7 @@ class CsvGeneratorColumnInline(admin.TabularInline):
     formset = CsvGeneratorColumnFormSet
     verbose_name = 'Column'
     verbose_name_plural = 'Columns'
-    extra = 1
+    extra = 0
 
 
 class CsvGeneratorAdmin(CsvExportAdmin):
